"""
Helper methods for format conversion.
"""

import mimetypes
import os
from urllib.parse import urlparse


def _get_dc_formats(self, resources) -> list[dict[str, str]]:
    """Returns resources formats in DataCite "formats" tag format."""
    dc_formats = []

    for resource in resources:
        resource_format = _get_format(self, resource)

        dc_format = {self.text_tag: resource_format}
        dc_formats += [dc_format]

    return dc_formats


def _get_format(self, resource):
    resource_format = resource.get(self.mimetype)

    if not resource_format:
        url = resource.get(self.url_lowercase)
        # note: if this is tested on windows, mimetypes might differ. did not find a better solution so far
        if url.startswith(self.envidat_dataset_url):
            resource_format = mimetypes.guess_type(url)[0]
        if not resource_format:
            path = urlparse(url).path
            _, resource_format = os.path.splitext(path)
        if not resource_format:
            resource_format = self.no_info

    return resource_format
